==> haskell-pantry-0.1.1.1-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pantry
version: 0.1.1.1
id: pantry-0.1.1.1-8GdXKNkuAdxK6SWmHq0wfa
key: pantry-0.1.1.1-8GdXKNkuAdxK6SWmHq0wfa
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Content addressable Haskell package management
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/pantry/README.md>
category: Development
abi: c7c7ba6e1ea98350e7f0225dda0b4af0
exposed: True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
                Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
                Pantry.SQLite Pantry.Storage Pantry.Tree Pantry.Types
                System.IsWindows
import-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pantry-0.1.1.1
hs-libraries: HSpantry-0.1.1.1-8GdXKNkuAdxK6SWmHq0wfa
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G
    conduit-extra-1.3.4-ApR2ZiAyfO54oTAYFYfASb containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-ITlHlOh3QYv9px9t4j8BGR deepseq-1.4.4.0
    digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN directory-1.3.3.0
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div ghc-prim-0.5.3
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hpack-0.32.0-5xy6GsMspH2OlkH1JxHzW
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-client-tls-0.3.5.3-LHtZCdKJkqrHjfPnvP0juz
    http-conduit-2.3.7.1-G2w7vWPk1V4DF7fe0f7sBo
    http-download-0.1.0.0-JbG2gpTvEdbD0J13e3iE2P
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV integer-gmp-1.0.2.0
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mono-traversable-1.0.12.0-8Q7w8XKO9s15aUqz39IsXa mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    persistent-2.10.1-7pXWa2dlvJy4zQ0L3Ek9xr
    persistent-sqlite-2.10.5-50nqf6iuAfn3xxkdkDn2Fx
    persistent-template-2.7.2-4whWR0bvC4g9aYhEXioa9u
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-orphans-0.1.1.0-FvsggZqQMCv4R0lDICAxkU
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tar-conduit-0.3.2-6ZFMY00gmVh3qPCAa3giyE template-haskell-2.14.0.0
    text-1.2.3.1 text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.7-3p9top26QmdL7WioCb2df
    th-reify-many-0.1.9-AO2I3KZjoiS9IDtUI7zilG
    th-utilities-0.2.3.0-BAMbOtSNx1jEXhdt32Ufgr time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.2-GcrC5gzJJYy7QaoJJ7PWya
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
haddock-interfaces: /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html: /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pantry-0.1.1.1-44-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pantry
version: 0.1.1.1
id: pantry-0.1.1.1-DOdpkTcmPnvBHeoqLKexS0
key: pantry-0.1.1.1-DOdpkTcmPnvBHeoqLKexS0
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Content addressable Haskell package management
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/pantry/README.md>
category: Development
abi: 9d9ad34a2acbc5d105b6e6f1695e2869
exposed: True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
                Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
                Pantry.SQLite Pantry.Storage Pantry.Tree Pantry.Types
                System.IsWindows
import-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pantry-0.1.1.1
hs-libraries: HSpantry-0.1.1.1-DOdpkTcmPnvBHeoqLKexS0
depends:
    Cabal-2.4.0.1 aeson-1.4.4.0-B759jesA16BBzbLoqI31GW
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-4WoHy8vBnBFBnZww6g0450
    conduit-extra-1.3.4-L7lgAb062eI3vVnzXOYpfp containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-3tNyvOigHpY3c3BzcI1hHF deepseq-1.4.4.0
    digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN directory-1.3.3.0
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div ghc-prim-0.5.3
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hpack-0.33.0-F6e24ekX0NA4IW0n5moAIs
    http-client-0.6.4-73LSh37vIvj1AryXK8OuVy
    http-client-tls-0.3.5.3-AJTJBIV5vrc3ahkftogFpc
    http-conduit-2.3.7.2-6yMhRmZPd9ACoj6Kdqe6H6
    http-download-0.1.0.0-H7StZq0BwhAH7kchsnc81O
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV integer-gmp-1.0.2.0
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mono-traversable-1.0.13.0-JiWIZfNEbdbIK5pHkpTGpR mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    path-0.6.1-Dbf4RfDrHofHtc1bqSTwwN
    path-io-1.4.2-LC2bphiRDgqLbnvsCG1r2G
    persistent-2.10.1-9hMHVKxwS15GE6CcgnrRnW
    persistent-sqlite-2.10.5-61GCm6tT08A6CEOGjx9Oci
    persistent-template-2.7.2-HvMENDlNigJ1LWNgpBmpKE
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-orphans-0.1.1.0-6XzAsSbhw18Izs7D7sxy5d
    rio-prettyprint-0.1.0.0-JAD1qWV1ZUkEVIURfaM5Yw
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tar-conduit-0.3.2-KyOtbISl5eG2ehRM5xRvUn template-haskell-2.14.0.0
    text-1.2.3.1 text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.7-HghHJKVho5DVkBF1DPzmR
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
    th-utilities-0.2.3.0-5SPt1fQgUXV7oeO1YphjeV time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.1.2-AjYI0Wfy3aJHPM2x33EWtg
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
haddock-interfaces: /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html: /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
